#!/bin/bash -e
set -o pipefail

kapply() {
    for f in "$@"; do
        kubectl apply --server-side \
            -f<(envsubst "$(env | sed 's/^/$/')" < "manifests/$f")
    done
}; export -f kapply

kcreatesec() {
    kubectl apply --server-side \
        -f<(kubectl create secret generic --dry-run=client -oyaml "$@")
}; export -f kcreatesec

kcreatecm() {
    kubectl apply --server-side \
        -f<(kubectl create configmap --dry-run=client -oyaml "$@")
}; export -f kcreatecm

kgseckey() {
    local sec="$1"; shift
    local key="$1"; shift

    kubectl get secret "$sec" -ojson | jq -re ".data.\"$key\"" | base64 -d
}; export -f kgseckey

kgcmkey() {
    local cm="$1";  shift
    local key="$1"; shift

    kubectl get configmap "$cm" -ojson | jq -re ".data.\"$key\""
}; export -f kgcmkey


kcreatesec searxng \
    --from-literal=SEARXNG_SECRET="$(kgseckey searxng SEARXNG_SECRET || openssl rand -hex 32)"

opts=()
for f in config/*; do
    opts+=(--from-file="$f")
done
kcreatecm searxng "${opts[@]}"

kapply common/valkey.yaml common/app.yaml

kubectl rollout restart deployment app
